@@ -1,12 +1,7 @@
 /*
- * Copyright Stalwart Labs, Minter Ltd. See the COPYING
- * file at the top-level directory of this distribution.
+ * SPDX-FileCopyrightText: 2020 Stalwart Labs LLC <hello@stalw.art>
  *
- * Licensed under the Apache License, Version 2.0 <LICENSE-APACHE or
- * https://www.apache.org/licenses/LICENSE-2.0> or the MIT license
- * <LICENSE-MIT or https://opensource.org/licenses/MIT>, at your
- * option. This file may not be copied, modified, or distributed
- * except according to those terms.
+ * SPDX-License-Identifier: Apache-2.0 OR MIT
  */
 
 fn single_byte_decoder(table: &[char], bytes: &[u8]) -> String {
@@ -20,115 +15,143 @@ fn single_byte_decoder(table: &[char], bytes: &[u8]) -> String {
     result
 }
 
-pub fn decoder_iso_8859_1(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_iso_8859_1(bytes: &[u8]) -> String {
     single_byte_decoder(ISO_8859_1, bytes)
 }
 
-pub fn decoder_iso_8859_2(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_iso_8859_2(bytes: &[u8]) -> String {
     single_byte_decoder(ISO_8859_2, bytes)
 }
 
-pub fn decoder_iso_8859_3(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_iso_8859_3(bytes: &[u8]) -> String {
     single_byte_decoder(ISO_8859_3, bytes)
 }
 
-pub fn decoder_iso_8859_4(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_iso_8859_4(bytes: &[u8]) -> String {
     single_byte_decoder(ISO_8859_4, bytes)
 }
 
-pub fn decoder_iso_8859_5(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_iso_8859_5(bytes: &[u8]) -> String {
     single_byte_decoder(ISO_8859_5, bytes)
 }
 
-pub fn decoder_iso_8859_6(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_iso_8859_6(bytes: &[u8]) -> String {
     single_byte_decoder(ISO_8859_6, bytes)
 }
 
-pub fn decoder_iso_8859_7(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_iso_8859_7(bytes: &[u8]) -> String {
     single_byte_decoder(ISO_8859_7, bytes)
 }
 
-pub fn decoder_iso_8859_8(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_iso_8859_8(bytes: &[u8]) -> String {
     single_byte_decoder(ISO_8859_8, bytes)
 }
 
-pub fn decoder_iso_8859_9(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_iso_8859_9(bytes: &[u8]) -> String {
     single_byte_decoder(ISO_8859_9, bytes)
 }
 
-pub fn decoder_iso_8859_10(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_iso_8859_10(bytes: &[u8]) -> String {
     single_byte_decoder(ISO_8859_10, bytes)
 }
 
-pub fn decoder_iso_8859_13(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_iso_8859_13(bytes: &[u8]) -> String {
     single_byte_decoder(ISO_8859_13, bytes)
 }
 
-pub fn decoder_iso_8859_14(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_iso_8859_14(bytes: &[u8]) -> String {
     single_byte_decoder(ISO_8859_14, bytes)
 }
 
-pub fn decoder_iso_8859_15(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_iso_8859_15(bytes: &[u8]) -> String {
     single_byte_decoder(ISO_8859_15, bytes)
 }
 
-pub fn decoder_iso_8859_16(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_iso_8859_16(bytes: &[u8]) -> String {
     single_byte_decoder(ISO_8859_16, bytes)
 }
 
-pub fn decoder_cp1250(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_cp1250(bytes: &[u8]) -> String {
     single_byte_decoder(CP1250, bytes)
 }
 
-pub fn decoder_cp1251(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_cp1251(bytes: &[u8]) -> String {
     single_byte_decoder(CP1251, bytes)
 }
 
-pub fn decoder_cp1252(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_cp1252(bytes: &[u8]) -> String {
     single_byte_decoder(CP1252, bytes)
 }
 
-pub fn decoder_cp1253(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_cp1253(bytes: &[u8]) -> String {
     single_byte_decoder(CP1253, bytes)
 }
 
-pub fn decoder_cp1254(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_cp1254(bytes: &[u8]) -> String {
     single_byte_decoder(CP1254, bytes)
 }
 
-pub fn decoder_cp1255(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_cp1255(bytes: &[u8]) -> String {
     single_byte_decoder(CP1255, bytes)
 }
 
-pub fn decoder_cp1256(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_cp1256(bytes: &[u8]) -> String {
     single_byte_decoder(CP1256, bytes)
 }
 
-pub fn decoder_cp1257(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_cp1257(bytes: &[u8]) -> String {
     single_byte_decoder(CP1257, bytes)
 }
 
-pub fn decoder_cp1258(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_cp1258(bytes: &[u8]) -> String {
     single_byte_decoder(CP1258, bytes)
 }
 
-pub fn decoder_koi8_r(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_koi8_r(bytes: &[u8]) -> String {
     single_byte_decoder(KOI8_R, bytes)
 }
 
-pub fn decoder_koi8_u(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_koi8_u(bytes: &[u8]) -> String {
     single_byte_decoder(KOI8_U, bytes)
 }
 
-pub fn decoder_macintosh(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_macintosh(bytes: &[u8]) -> String {
     single_byte_decoder(MACINTOSH, bytes)
 }
 
-pub fn decoder_ibm_850(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_ibm_850(bytes: &[u8]) -> String {
     single_byte_decoder(IBM850, bytes)
 }
 
-pub fn decoder_tis_620(bytes: &[u8]) -> String {
+#[inline(always)]
+pub(crate) fn decoder_tis_620(bytes: &[u8]) -> String {
     single_byte_decoder(TIS_620, bytes)
 }
 
